import{j as s}from"./@radix-AvWw-1nd.js";import{bd as c,n as i}from"./index-DWoLoYDY.js";import{S as e}from"./check-DZ0KAh3W.js";function n({tickClasses:r,...o}){return s.jsx(c,{...o,children:s.jsx(e,{className:i("h-4 w-4 fill-success-300",r)})})}export{n as T};
