import{j as o}from"./@radix-AvWw-1nd.js";import{S as r}from"./Tabs-BEWDPvPV.js";import{R as m}from"./RunsBody-D2VoO-cR.js";import{R as i}from"./RunSelector-CYmRHGdm.js";import{S as p}from"./StackList-C8KNd00o.js";import{b as s}from"./@react-router-BUo5vhN4.js";import"./index-DWoLoYDY.js";import"./@tanstack-CcI3lvwB.js";import"./@reactflow-DMaYqp8l.js";import"./chevron-down-A3PXOshS.js";import"./NestedCollapsible-CE4OF670.js";import"./type-guards-CaeD8wHO.js";import"./CodeSnippet-D8ptwPjg.js";import"./CollapsibleCard-Djtd_ocf.js";import"./DisplayDate-C5Aw-Yca.js";import"./InlineAvatar-Bk4QLPTU.js";import"./refresh-CupyU1Vs.js";import"./SearchField-DfNxVtjV.js";import"./chevron-right-double-zKz7rAaU.js";import"./index-BVVKxTWC.js";import"./all-pipeline-runs-query-B509kMlL.js";import"./ExecutionStatus-DHiK3Am-.js";import"./check-circle-DyCCYTA0.js";import"./trash-B_JgTgqd.js";import"./DeleteAlertDialog-CTLRrcFM.js";import"./zod-CRNUMWWg.js";import"./index.esm-cf-8NBxV.js";import"./AlertDialogDropdownItem-XL2NfFgP.js";import"./delete-run-CzPWbsBy.js";import"./plus-CoKtHiA9.js";import"./index-CaRx22lH.js";import"./stack-detail-query-CI_YMUx6.js";import"./components-Br2ezRib.js";import"./NumberBox-BvBJYxCu.js";import"./ComponentBadge-CVN2FsiW.js";import"./ComponentIcon-gpMJ2Y2e.js";import"./layout-3_rgDUxf.js";import"./rocket-k68ONPDS.js";import"./transform-DKsRLKTv.js";import"./DialogItem-ST291Hsl.js";import"./Infobox-DYKoAVhW.js";function V(){const{componentId:t}=s();return o.jsx("div",{className:"@container",children:o.jsx(r,{isPanel:!1,stacksTabContent:o.jsx(p,{fixedQueryParams:{component_id:t}}),runsTabContent:o.jsx(i,{children:o.jsx(m,{fixedQueryParams:{stack_component:t}})}),componentId:t})})}export{V as default};
