import{j as e}from"./@radix-AvWw-1nd.js";import{j as r,X as a}from"./index-DWoLoYDY.js";import{E as l}from"./EmptyState-DpbfQBDE.js";function c({err:t,isAlertCircle:s=!1}){return e.jsx(l,{icon:s?e.jsx(r,{className:"h-[120px] w-[120px] fill-neutral-300"}):e.jsx(a,{className:"h-[120px] w-[120px] fill-neutral-300"}),children:e.jsx("div",{className:"text-center",children:e.jsx("p",{className:"text-text-lg text-theme-text-secondary",children:t.message})})})}export{c as E};
