"""Release [0.67.0].

Revision ID: 0.67.0
Revises: 0.66.0
Create Date: 2024-09-25 10:39:36.711715

"""

# revision identifiers, used by Alembic.
revision = "0.67.0"
down_revision = "0.66.0"
branch_labels = None
depends_on = None


def upgrade() -> None:
    """Upgrade database schema and/or data, creating a new revision."""
    pass


def downgrade() -> None:
    """Downgrade database schema and/or data back to the previous revision."""
    pass
